defmodule Nulla.ActivitiesTest do
  use Nulla.DataCase

  alias Nulla.Activities

  describe "activities" do
    alias Nulla.Activities.Activity

    import Nulla.ActivitiesFixtures

    @invalid_attrs %{type: nil, cc: nil, to: nil, ap_id: nil, actor: nil, object: nil}

    test "list_activities/0 returns all activities" do
      activity = activity_fixture()
      assert Activities.list_activities() == [activity]
    end

    test "get_activity!/1 returns the activity with given id" do
      activity = activity_fixture()
      assert Activities.get_activity!(activity.id) == activity
    end

    test "create_activity/1 with valid data creates a activity" do
      valid_attrs = %{
        type: "some type",
        cc: ["option1", "option2"],
        to: ["option1", "option2"],
        ap_id: "some ap_id",
        actor: "some actor",
        object: "some object"
      }

      assert {:ok, %Activity{} = activity} = Activities.create_activity(valid_attrs)
      assert activity.type == "some type"
      assert activity.cc == ["option1", "option2"]
      assert activity.to == ["option1", "option2"]
      assert activity.ap_id == "some ap_id"
      assert activity.actor == "some actor"
      assert activity.object == "some object"
    end

    test "create_activity/1 with invalid data returns error changeset" do
      assert {:error, %Ecto.Changeset{}} = Activities.create_activity(@invalid_attrs)
    end

    test "update_activity/2 with valid data updates the activity" do
      activity = activity_fixture()

      update_attrs = %{
        type: "some updated type",
        cc: ["option1"],
        to: ["option1"],
        ap_id: "some updated ap_id",
        actor: "some updated actor",
        object: "some updated object"
      }

      assert {:ok, %Activity{} = activity} = Activities.update_activity(activity, update_attrs)
      assert activity.type == "some updated type"
      assert activity.cc == ["option1"]
      assert activity.to == ["option1"]
      assert activity.ap_id == "some updated ap_id"
      assert activity.actor == "some updated actor"
      assert activity.object == "some updated object"
    end

    test "update_activity/2 with invalid data returns error changeset" do
      activity = activity_fixture()
      assert {:error, %Ecto.Changeset{}} = Activities.update_activity(activity, @invalid_attrs)
      assert activity == Activities.get_activity!(activity.id)
    end

    test "delete_activity/1 deletes the activity" do
      activity = activity_fixture()
      assert {:ok, %Activity{}} = Activities.delete_activity(activity)
      assert_raise Ecto.NoResultsError, fn -> Activities.get_activity!(activity.id) end
    end

    test "change_activity/1 returns a activity changeset" do
      activity = activity_fixture()
      assert %Ecto.Changeset{} = Activities.change_activity(activity)
    end
  end
end
