defmodule Nulla.HTTPSignatureTest do
  use NullaWeb.ConnCase, async: false
  import Plug.Conn
  import Plug.Test
  import Nulla.ActorsFixtures
  alias Nulla.HTTPSignature
  alias Nulla.Snowflake

  test "make_headers/3 creates valid signature headers and verify/2 validates them" do
    actor = actor_fixture()
    target_actor = actor_fixture()

    follow_activity = %{
      "@context" => "https://www.w3.org/ns/activitystreams",
      "id" => Snowflake.next_id(),
      "type" => "Follow",
      "actor" => actor.ap_id,
      "object" => target_actor.ap_id
    }

    body = Jason.encode!(follow_activity)

    headers =
      HTTPSignature.make_headers(
        body,
        target_actor.inbox,
        actor.publicKey["id"],
        actor.privateKeyPem
      )

    conn =
      conn(:post, "/users/#{target_actor.preferredUsername}/inbox", body)
      |> put_req_header("content-type", Map.new(headers) |> Map.get("Content-Type"))
      |> put_req_header("date", Map.new(headers) |> Map.get("Date"))
      |> put_req_header("digest", Map.new(headers) |> Map.get("Digest"))
      |> put_req_header("signature", Map.new(headers) |> Map.get("Signature"))
      |> Map.put(:host, URI.parse(target_actor.inbox).host)

    assert :ok = HTTPSignature.verify(conn, actor.publicKey["publicKeyPem"])
  end
end
