defmodule Nulla.MediaAttachmentsTest do
  use Nulla.DataCase

  alias Nulla.MediaAttachments

  describe "media_attachments" do
    alias Nulla.MediaAttachments.MediaAttachment

    import Nulla.NotesFixtures
    import Nulla.MediaAttachmentsFixtures

    @invalid_attrs %{
      name: nil,
      type: nil,
      width: nil,
      url: nil,
      mediaType: nil,
      height: nil,
      note_id: nil
    }

    test "list_media_attachments/0 returns all media_attachments" do
      media_attachment = media_attachment_fixture()
      assert MediaAttachments.list_media_attachments() == [media_attachment]
    end

    test "get_media_attachment!/1 returns the media_attachment with given id" do
      media_attachment = media_attachment_fixture()
      assert MediaAttachments.get_media_attachment!(media_attachment.id) == media_attachment
    end

    test "create_media_attachment/1 with valid data creates a media_attachment" do
      note = note_fixture()

      valid_attrs = %{
        name: "some name",
        type: "some type",
        width: 42,
        url: "some url",
        mediaType: "some mediaType",
        height: 42,
        note_id: note.id
      }

      assert {:ok, %MediaAttachment{} = media_attachment} =
               MediaAttachments.create_media_attachment(valid_attrs)

      assert media_attachment.name == "some name"
      assert media_attachment.type == "some type"
      assert media_attachment.width == 42
      assert media_attachment.url == "some url"
      assert media_attachment.mediaType == "some mediaType"
      assert media_attachment.height == 42
      assert media_attachment.note_id == note.id
    end

    test "create_media_attachment/1 with invalid data returns error changeset" do
      assert {:error, %Ecto.Changeset{}} =
               MediaAttachments.create_media_attachment(@invalid_attrs)
    end

    test "update_media_attachment/2 with valid data updates the media_attachment" do
      note = note_fixture()
      media_attachment = media_attachment_fixture()

      update_attrs = %{
        name: "some updated name",
        type: "some updated type",
        width: 43,
        url: "some updated url",
        mediaType: "some updated mediaType",
        height: 43,
        note_id: note.id
      }

      assert {:ok, %MediaAttachment{} = media_attachment} =
               MediaAttachments.update_media_attachment(media_attachment, update_attrs)

      assert media_attachment.name == "some updated name"
      assert media_attachment.type == "some updated type"
      assert media_attachment.width == 43
      assert media_attachment.url == "some updated url"
      assert media_attachment.mediaType == "some updated mediaType"
      assert media_attachment.height == 43
      assert media_attachment.note_id == note.id
    end

    test "update_media_attachment/2 with invalid data returns error changeset" do
      media_attachment = media_attachment_fixture()

      assert {:error, %Ecto.Changeset{}} =
               MediaAttachments.update_media_attachment(media_attachment, @invalid_attrs)

      assert media_attachment == MediaAttachments.get_media_attachment!(media_attachment.id)
    end

    test "delete_media_attachment/1 deletes the media_attachment" do
      media_attachment = media_attachment_fixture()

      assert {:ok, %MediaAttachment{}} =
               MediaAttachments.delete_media_attachment(media_attachment)

      assert_raise Ecto.NoResultsError, fn ->
        MediaAttachments.get_media_attachment!(media_attachment.id)
      end
    end

    test "change_media_attachment/1 returns a media_attachment changeset" do
      media_attachment = media_attachment_fixture()
      assert %Ecto.Changeset{} = MediaAttachments.change_media_attachment(media_attachment)
    end
  end
end
